# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .merging_strategy import MergingStrategy
from .multi_source_config_json import MultiSourceConfigJson
from .source_config_json import SourceConfigJson


class SearchDocumentationToolConfigOutput(UncheckedBaseModel):
    """
    System tool for searching ElevenLabs documentation using RAG.

    This tool provides access to:
    - Product documentation
    - API references
    - Pricing information
    - Troubleshooting guides
    - Best practices

    It uses a flexible multi-source approach with configurable:
    - Document sources with per-source k for dense/keyword retrieval
    - Merging strategies (RRF, top-K per source, weighted interleave)
    - Query decomposition and reformulation
    - LLM synthesis vs raw chunks
    """

    use_multi_source: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Use the new multi-source retrieval engine
    """

    multi_source_config: typing.Optional[MultiSourceConfigJson] = pydantic.Field(default=None)
    """
    Full multi-source configuration as JSON. Takes precedence over individual fields. Example: {'source_names': ['chunks'], 'use_decomposition': true, 'final_top_k': 5}
    """

    use_decomposition: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Decompose complex queries into sub-queries
    """

    use_reformulation: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Use LLM to reformulate query for better retrieval
    """

    synthesize_response: typing.Optional[bool] = pydantic.Field(default=None)
    """
    True = LLM generates answer, False = return raw chunks
    """

    merging_strategy: typing.Optional[MergingStrategy] = pydantic.Field(default=None)
    """
    Strategy for merging results: 'top_k_per_source' (concatenate), 'rank_fusion' (RRF), 'weighted_interleave'
    """

    final_top_k: typing.Optional[int] = pydantic.Field(default=None)
    """
    Final number of chunks after merging
    """

    source_names: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of source names to use (e.g., ['chunks', 'products']). Defaults to both 'products' and 'chunks'. Unknown sources are ignored with a warning.
    """

    source_overrides: typing.Optional[typing.List[SourceConfigJson]] = pydantic.Field(default=None)
    """
    Per-source parameter overrides as JSON. Example: [{'name': 'chunks', 'k_dense': 10, 'k_keyword': 5}]
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class SourceRetrievalConfig(UncheckedBaseModel):
    name: str
    collection_name: str
    db_name: typing.Optional[str] = None
    enabled: typing.Optional[bool] = None
    k_dense: typing.Optional[int] = None
    k_keyword: typing.Optional[int] = None
    dense_weight: typing.Optional[float] = None
    keyword_weight: typing.Optional[float] = None
    source_weight: typing.Optional[float] = None
    vector_index_name: typing.Optional[str] = None
    embedding_field: typing.Optional[str] = None
    content_field: typing.Optional[str] = None
    filter_field: typing.Optional[str] = None
    num_candidates_multiplier: typing.Optional[int] = None
    result_fields: typing.Optional[typing.Dict[str, typing.List[typing.Any]]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .conversation_history_transcript_common_model_input import ConversationHistoryTranscriptCommonModelInput
from .create_tool_call_unit_test_request_dynamic_variables_value import (
    CreateToolCallUnitTestRequestDynamicVariablesValue,
)
from .test_from_conversation_metadata_input import TestFromConversationMetadataInput
from .unit_test_tool_call_evaluation_model_input import UnitTestToolCallEvaluationModelInput


class CreateToolCallUnitTestRequest(UncheckedBaseModel):
    from_conversation_metadata: typing.Optional[TestFromConversationMetadataInput] = pydantic.Field(default=None)
    """
    Metadata of a conversation this test was created from (if applicable).
    """

    dynamic_variables: typing.Optional[
        typing.Dict[str, typing.Optional[CreateToolCallUnitTestRequestDynamicVariablesValue]]
    ] = pydantic.Field(default=None)
    """
    Dynamic variables to replace in the agent config during testing
    """

    chat_history: typing.Optional[typing.List[ConversationHistoryTranscriptCommonModelInput]] = None
    tool_call_parameters: typing.Optional[UnitTestToolCallEvaluationModelInput] = pydantic.Field(default=None)
    """
    How to evaluate the agent's tool call (if any). If empty, the tool call is not evaluated.
    """

    check_any_tool_matches: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If set to True this test will pass if any tool call returned by the LLM matches the criteria. Otherwise it will fail if more than one tool is returned by the agent.
    """

    name: str
    parent_folder_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the parent folder. If not provided, the test will be created at the root level.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(CreateToolCallUnitTestRequest)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .conversation_history_transcript_common_model_output import ConversationHistoryTranscriptCommonModelOutput
from .simulation_test_model_dynamic_variables_value import SimulationTestModelDynamicVariablesValue
from .test_from_conversation_metadata_output import TestFromConversationMetadataOutput


class SimulationTestModel(UncheckedBaseModel):
    from_conversation_metadata: typing.Optional[TestFromConversationMetadataOutput] = pydantic.Field(default=None)
    """
    Metadata of a conversation this test was created from (if applicable).
    """

    dynamic_variables: typing.Optional[typing.Dict[str, typing.Optional[SimulationTestModelDynamicVariablesValue]]] = (
        pydantic.Field(default=None)
    )
    """
    Dynamic variables to replace in the agent config during testing
    """

    chat_history: typing.Optional[typing.List[ConversationHistoryTranscriptCommonModelOutput]] = None
    success_condition: typing.Optional[str] = pydantic.Field(default=None)
    """
    A prompt that evaluates whether the agent's response is successful. Should return True or False.
    """

    simulation_scenario: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description of the simulation scenario and user persona for simulation tests.
    """

    simulation_max_turns: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum number of conversation turns for simulation tests.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(SimulationTestModel)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.conversation_initiation_source import ConversationInitiationSource
from ...types.conversation_signed_url_response_model import ConversationSignedUrlResponseModel
from ...types.evaluation_success_result import EvaluationSuccessResult
from ...types.get_conversation_response_model import GetConversationResponseModel
from ...types.get_conversations_page_response_model import GetConversationsPageResponseModel
from ...types.token_response_model import TokenResponseModel
from .raw_client import AsyncRawConversationsClient, RawConversationsClient
from .types.conversations_list_request_summary_mode import ConversationsListRequestSummaryMode

if typing.TYPE_CHECKING:
    from .audio.client import AsyncAudioClient, AudioClient
    from .feedback.client import AsyncFeedbackClient, FeedbackClient
    from .files.client import AsyncFilesClient, FilesClient
    from .messages.client import AsyncMessagesClient, MessagesClient


class ConversationsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawConversationsClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._audio: typing.Optional[AudioClient] = None
        self._feedback: typing.Optional[FeedbackClient] = None
        self._messages: typing.Optional[MessagesClient] = None
        self._files: typing.Optional[FilesClient] = None

    @property
    def with_raw_response(self) -> RawConversationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawConversationsClient
        """
        return self._raw_client

    def get_signed_url(
        self,
        *,
        agent_id: str,
        include_conversation_id: typing.Optional[bool] = None,
        branch_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConversationSignedUrlResponseModel:
        """
        Get a signed url to start a conversation with an agent with an agent that requires authorization

        Parameters
        ----------
        agent_id : str
            The id of the agent you're taking the action on.

        include_conversation_id : typing.Optional[bool]
            Whether to include a conversation_id with the response. If included, the conversation_signature cannot be used again.

        branch_id : typing.Optional[str]
            The ID of the branch to use

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConversationSignedUrlResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.get_signed_url(
            agent_id="21m00Tcm4TlvDq8ikWAM",
            include_conversation_id=True,
            branch_id="branch_id",
        )
        """
        _response = self._raw_client.get_signed_url(
            agent_id=agent_id,
            include_conversation_id=include_conversation_id,
            branch_id=branch_id,
            request_options=request_options,
        )
        return _response.data

    def get_webrtc_token(
        self,
        *,
        agent_id: str,
        participant_name: typing.Optional[str] = None,
        branch_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TokenResponseModel:
        """
        Get a WebRTC session token for real-time communication.

        Parameters
        ----------
        agent_id : str
            The id of the agent you're taking the action on.

        participant_name : typing.Optional[str]
            Optional custom participant name. If not provided, user ID will be used

        branch_id : typing.Optional[str]
            The ID of the branch to use

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TokenResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.get_webrtc_token(
            agent_id="21m00Tcm4TlvDq8ikWAM",
            participant_name="participant_name",
            branch_id="branch_id",
        )
        """
        _response = self._raw_client.get_webrtc_token(
            agent_id=agent_id, participant_name=participant_name, branch_id=branch_id, request_options=request_options
        )
        return _response.data

    def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        agent_id: typing.Optional[str] = None,
        call_successful: typing.Optional[EvaluationSuccessResult] = None,
        call_start_before_unix: typing.Optional[int] = None,
        call_start_after_unix: typing.Optional[int] = None,
        call_duration_min_secs: typing.Optional[int] = None,
        call_duration_max_secs: typing.Optional[int] = None,
        rating_max: typing.Optional[int] = None,
        rating_min: typing.Optional[int] = None,
        has_feedback_comment: typing.Optional[bool] = None,
        user_id: typing.Optional[str] = None,
        evaluation_params: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        data_collection_params: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        tool_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        main_languages: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        page_size: typing.Optional[int] = None,
        summary_mode: typing.Optional[ConversationsListRequestSummaryMode] = None,
        search: typing.Optional[str] = None,
        conversation_initiation_source: typing.Optional[ConversationInitiationSource] = None,
        branch_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetConversationsPageResponseModel:
        """
        Get all conversations of agents that user owns. With option to restrict to a specific agent.

        Parameters
        ----------
        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        agent_id : typing.Optional[str]
            The id of the agent you're taking the action on.

        call_successful : typing.Optional[EvaluationSuccessResult]
            The result of the success evaluation

        call_start_before_unix : typing.Optional[int]
            Unix timestamp (in seconds) to filter conversations up to this start date.

        call_start_after_unix : typing.Optional[int]
            Unix timestamp (in seconds) to filter conversations after to this start date.

        call_duration_min_secs : typing.Optional[int]
            Minimum call duration in seconds.

        call_duration_max_secs : typing.Optional[int]
            Maximum call duration in seconds.

        rating_max : typing.Optional[int]
            Maximum overall rating (1-5).

        rating_min : typing.Optional[int]
            Minimum overall rating (1-5).

        has_feedback_comment : typing.Optional[bool]
            Filter conversations with user feedback comments.

        user_id : typing.Optional[str]
            Filter conversations by the user ID who initiated them.

        evaluation_params : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Evaluation filters. Repeat param. Format: criteria_id:result. Example: eval=value_framing:success

        data_collection_params : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Data collection filters. Repeat param. Format: id:op:value where op is one of eq|neq|gt|gte|lt|lte|in|exists|missing. For in, pipe-delimit values.

        tool_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Filter conversations by tool names used during the call.

        main_languages : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Filter conversations by detected main language (language code).

        page_size : typing.Optional[int]
            How many conversations to return at maximum. Can not exceed 100, defaults to 30.

        summary_mode : typing.Optional[ConversationsListRequestSummaryMode]
            Whether to include transcript summaries in the response.

        search : typing.Optional[str]
            Full-text or fuzzy search over transcript messages

        conversation_initiation_source : typing.Optional[ConversationInitiationSource]

        branch_id : typing.Optional[str]
            Filter conversations by branch ID.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetConversationsPageResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.list(
            cursor="cursor",
            agent_id="agent_id",
            call_successful="success",
            call_start_before_unix=1,
            call_start_after_unix=1,
            call_duration_min_secs=1,
            call_duration_max_secs=1,
            rating_max=1,
            rating_min=1,
            has_feedback_comment=True,
            user_id="user_id",
            page_size=1,
            summary_mode="exclude",
            search="search",
            conversation_initiation_source="unknown",
            branch_id="branch_id",
        )
        """
        _response = self._raw_client.list(
            cursor=cursor,
            agent_id=agent_id,
            call_successful=call_successful,
            call_start_before_unix=call_start_before_unix,
            call_start_after_unix=call_start_after_unix,
            call_duration_min_secs=call_duration_min_secs,
            call_duration_max_secs=call_duration_max_secs,
            rating_max=rating_max,
            rating_min=rating_min,
            has_feedback_comment=has_feedback_comment,
            user_id=user_id,
            evaluation_params=evaluation_params,
            data_collection_params=data_collection_params,
            tool_names=tool_names,
            main_languages=main_languages,
            page_size=page_size,
            summary_mode=summary_mode,
            search=search,
            conversation_initiation_source=conversation_initiation_source,
            branch_id=branch_id,
            request_options=request_options,
        )
        return _response.data

    def get(
        self, conversation_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetConversationResponseModel:
        """
        Get the details of a particular conversation

        Parameters
        ----------
        conversation_id : str
            The id of the conversation you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetConversationResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.get(
            conversation_id="123",
        )
        """
        _response = self._raw_client.get(conversation_id, request_options=request_options)
        return _response.data

    def delete(self, conversation_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Delete a particular conversation

        Parameters
        ----------
        conversation_id : str
            The id of the conversation you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.conversations.delete(
            conversation_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._raw_client.delete(conversation_id, request_options=request_options)
        return _response.data

    @property
    def audio(self):
        if self._audio is None:
            from .audio.client import AudioClient  # noqa: E402

            self._audio = AudioClient(client_wrapper=self._client_wrapper)
        return self._audio

    @property
    def feedback(self):
        if self._feedback is None:
            from .feedback.client import FeedbackClient  # noqa: E402

            self._feedback = FeedbackClient(client_wrapper=self._client_wrapper)
        return self._feedback

    @property
    def messages(self):
        if self._messages is None:
            from .messages.client import MessagesClient  # noqa: E402

            self._messages = MessagesClient(client_wrapper=self._client_wrapper)
        return self._messages

    @property
    def files(self):
        if self._files is None:
            from .files.client import FilesClient  # noqa: E402

            self._files = FilesClient(client_wrapper=self._client_wrapper)
        return self._files


class AsyncConversationsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawConversationsClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._audio: typing.Optional[AsyncAudioClient] = None
        self._feedback: typing.Optional[AsyncFeedbackClient] = None
        self._messages: typing.Optional[AsyncMessagesClient] = None
        self._files: typing.Optional[AsyncFilesClient] = None

    @property
    def with_raw_response(self) -> AsyncRawConversationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawConversationsClient
        """
        return self._raw_client

    async def get_signed_url(
        self,
        *,
        agent_id: str,
        include_conversation_id: typing.Optional[bool] = None,
        branch_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConversationSignedUrlResponseModel:
        """
        Get a signed url to start a conversation with an agent with an agent that requires authorization

        Parameters
        ----------
        agent_id : str
            The id of the agent you're taking the action on.

        include_conversation_id : typing.Optional[bool]
            Whether to include a conversation_id with the response. If included, the conversation_signature cannot be used again.

        branch_id : typing.Optional[str]
            The ID of the branch to use

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConversationSignedUrlResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.get_signed_url(
                agent_id="21m00Tcm4TlvDq8ikWAM",
                include_conversation_id=True,
                branch_id="branch_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_signed_url(
            agent_id=agent_id,
            include_conversation_id=include_conversation_id,
            branch_id=branch_id,
            request_options=request_options,
        )
        return _response.data

    async def get_webrtc_token(
        self,
        *,
        agent_id: str,
        participant_name: typing.Optional[str] = None,
        branch_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TokenResponseModel:
        """
        Get a WebRTC session token for real-time communication.

        Parameters
        ----------
        agent_id : str
            The id of the agent you're taking the action on.

        participant_name : typing.Optional[str]
            Optional custom participant name. If not provided, user ID will be used

        branch_id : typing.Optional[str]
            The ID of the branch to use

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TokenResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.get_webrtc_token(
                agent_id="21m00Tcm4TlvDq8ikWAM",
                participant_name="participant_name",
                branch_id="branch_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_webrtc_token(
            agent_id=agent_id, participant_name=participant_name, branch_id=branch_id, request_options=request_options
        )
        return _response.data

    async def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        agent_id: typing.Optional[str] = None,
        call_successful: typing.Optional[EvaluationSuccessResult] = None,
        call_start_before_unix: typing.Optional[int] = None,
        call_start_after_unix: typing.Optional[int] = None,
        call_duration_min_secs: typing.Optional[int] = None,
        call_duration_max_secs: typing.Optional[int] = None,
        rating_max: typing.Optional[int] = None,
        rating_min: typing.Optional[int] = None,
        has_feedback_comment: typing.Optional[bool] = None,
        user_id: typing.Optional[str] = None,
        evaluation_params: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        data_collection_params: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        tool_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        main_languages: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        page_size: typing.Optional[int] = None,
        summary_mode: typing.Optional[ConversationsListRequestSummaryMode] = None,
        search: typing.Optional[str] = None,
        conversation_initiation_source: typing.Optional[ConversationInitiationSource] = None,
        branch_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetConversationsPageResponseModel:
        """
        Get all conversations of agents that user owns. With option to restrict to a specific agent.

        Parameters
        ----------
        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        agent_id : typing.Optional[str]
            The id of the agent you're taking the action on.

        call_successful : typing.Optional[EvaluationSuccessResult]
            The result of the success evaluation

        call_start_before_unix : typing.Optional[int]
            Unix timestamp (in seconds) to filter conversations up to this start date.

        call_start_after_unix : typing.Optional[int]
            Unix timestamp (in seconds) to filter conversations after to this start date.

        call_duration_min_secs : typing.Optional[int]
            Minimum call duration in seconds.

        call_duration_max_secs : typing.Optional[int]
            Maximum call duration in seconds.

        rating_max : typing.Optional[int]
            Maximum overall rating (1-5).

        rating_min : typing.Optional[int]
            Minimum overall rating (1-5).

        has_feedback_comment : typing.Optional[bool]
            Filter conversations with user feedback comments.

        user_id : typing.Optional[str]
            Filter conversations by the user ID who initiated them.

        evaluation_params : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Evaluation filters. Repeat param. Format: criteria_id:result. Example: eval=value_framing:success

        data_collection_params : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Data collection filters. Repeat param. Format: id:op:value where op is one of eq|neq|gt|gte|lt|lte|in|exists|missing. For in, pipe-delimit values.

        tool_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Filter conversations by tool names used during the call.

        main_languages : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Filter conversations by detected main language (language code).

        page_size : typing.Optional[int]
            How many conversations to return at maximum. Can not exceed 100, defaults to 30.

        summary_mode : typing.Optional[ConversationsListRequestSummaryMode]
            Whether to include transcript summaries in the response.

        search : typing.Optional[str]
            Full-text or fuzzy search over transcript messages

        conversation_initiation_source : typing.Optional[ConversationInitiationSource]

        branch_id : typing.Optional[str]
            Filter conversations by branch ID.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetConversationsPageResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.list(
                cursor="cursor",
                agent_id="agent_id",
                call_successful="success",
                call_start_before_unix=1,
                call_start_after_unix=1,
                call_duration_min_secs=1,
                call_duration_max_secs=1,
                rating_max=1,
                rating_min=1,
                has_feedback_comment=True,
                user_id="user_id",
                page_size=1,
                summary_mode="exclude",
                search="search",
                conversation_initiation_source="unknown",
                branch_id="branch_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            cursor=cursor,
            agent_id=agent_id,
            call_successful=call_successful,
            call_start_before_unix=call_start_before_unix,
            call_start_after_unix=call_start_after_unix,
            call_duration_min_secs=call_duration_min_secs,
            call_duration_max_secs=call_duration_max_secs,
            rating_max=rating_max,
            rating_min=rating_min,
            has_feedback_comment=has_feedback_comment,
            user_id=user_id,
            evaluation_params=evaluation_params,
            data_collection_params=data_collection_params,
            tool_names=tool_names,
            main_languages=main_languages,
            page_size=page_size,
            summary_mode=summary_mode,
            search=search,
            conversation_initiation_source=conversation_initiation_source,
            branch_id=branch_id,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self, conversation_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetConversationResponseModel:
        """
        Get the details of a particular conversation

        Parameters
        ----------
        conversation_id : str
            The id of the conversation you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetConversationResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.get(
                conversation_id="123",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(conversation_id, request_options=request_options)
        return _response.data

    async def delete(
        self, conversation_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Delete a particular conversation

        Parameters
        ----------
        conversation_id : str
            The id of the conversation you're taking the action on.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.conversations.delete(
                conversation_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(conversation_id, request_options=request_options)
        return _response.data

    @property
    def audio(self):
        if self._audio is None:
            from .audio.client import AsyncAudioClient  # noqa: E402

            self._audio = AsyncAudioClient(client_wrapper=self._client_wrapper)
        return self._audio

    @property
    def feedback(self):
        if self._feedback is None:
            from .feedback.client import AsyncFeedbackClient  # noqa: E402

            self._feedback = AsyncFeedbackClient(client_wrapper=self._client_wrapper)
        return self._feedback

    @property
    def messages(self):
        if self._messages is None:
            from .messages.client import AsyncMessagesClient  # noqa: E402

            self._messages = AsyncMessagesClient(client_wrapper=self._client_wrapper)
        return self._messages

    @property
    def files(self):
        if self._files is None:
            from .files.client import AsyncFilesClient  # noqa: E402

            self._files = AsyncFilesClient(client_wrapper=self._client_wrapper)
        return self._files



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .attached_test_model import AttachedTestModel


class AgentTestingSettings(UncheckedBaseModel):
    """
    Settings for agent testing configuration.
    """

    attached_tests: typing.Optional[typing.List[AttachedTestModel]] = pydantic.Field(default=None)
    """
    List of test IDs that should be run for this agent
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .merging_strategy import MergingStrategy
from .source_config_json import SourceConfigJson


class MultiSourceConfigJson(UncheckedBaseModel):
    """
    JSON-serializable multi-source retrieval configuration.

    This can be passed as JSON in tool configurations for full control.
    """

    source_names: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of source names to use (e.g., ['chunks', 'products'])
    """

    source_overrides: typing.Optional[typing.List[SourceConfigJson]] = pydantic.Field(default=None)
    """
    Per-source parameter overrides
    """

    merging_strategy: typing.Optional[MergingStrategy] = pydantic.Field(default=None)
    """
    How to merge results from multiple sources
    """

    final_top_k: typing.Optional[int] = pydantic.Field(default=None)
    """
    Final number of chunks after merging
    """

    use_decomposition: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Decompose complex queries
    """

    use_reformulation: typing.Optional[bool] = pydantic.Field(default=None)
    """
    LLM reformulates query
    """

    synthesize_response: typing.Optional[bool] = pydantic.Field(default=None)
    """
    LLM generates answer vs raw chunks
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ....core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from ....types.agent_failure_response_example import AgentFailureResponseExample
from ....types.agent_successful_response_example import AgentSuccessfulResponseExample
from ....types.conversation_history_transcript_common_model_output import ConversationHistoryTranscriptCommonModelOutput
from ....types.get_response_unit_test_response_model_dynamic_variables_value import (
    GetResponseUnitTestResponseModelDynamicVariablesValue,
)
from ....types.get_simulation_test_response_model_dynamic_variables_value import (
    GetSimulationTestResponseModelDynamicVariablesValue,
)
from ....types.get_tool_call_unit_test_response_model_dynamic_variables_value import (
    GetToolCallUnitTestResponseModelDynamicVariablesValue,
)
from ....types.test_from_conversation_metadata_output import TestFromConversationMetadataOutput
from ....types.unit_test_tool_call_evaluation_model_output import UnitTestToolCallEvaluationModelOutput


class TestsUpdateResponse_Llm(UncheckedBaseModel):
    type: typing.Literal["llm"] = "llm"
    from_conversation_metadata: typing.Optional[TestFromConversationMetadataOutput] = None
    dynamic_variables: typing.Optional[
        typing.Dict[str, typing.Optional[GetResponseUnitTestResponseModelDynamicVariablesValue]]
    ] = None
    chat_history: typing.Optional[typing.List[ConversationHistoryTranscriptCommonModelOutput]] = None
    success_condition: typing.Optional[str] = None
    success_examples: typing.Optional[typing.List[AgentSuccessfulResponseExample]] = None
    failure_examples: typing.Optional[typing.List[AgentFailureResponseExample]] = None
    id: str
    name: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class TestsUpdateResponse_Tool(UncheckedBaseModel):
    type: typing.Literal["tool"] = "tool"
    from_conversation_metadata: typing.Optional[TestFromConversationMetadataOutput] = None
    dynamic_variables: typing.Optional[
        typing.Dict[str, typing.Optional[GetToolCallUnitTestResponseModelDynamicVariablesValue]]
    ] = None
    chat_history: typing.Optional[typing.List[ConversationHistoryTranscriptCommonModelOutput]] = None
    tool_call_parameters: typing.Optional[UnitTestToolCallEvaluationModelOutput] = None
    check_any_tool_matches: typing.Optional[bool] = None
    id: str
    name: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class TestsUpdateResponse_Simulation(UncheckedBaseModel):
    type: typing.Literal["simulation"] = "simulation"
    from_conversation_metadata: typing.Optional[TestFromConversationMetadataOutput] = None
    dynamic_variables: typing.Optional[
        typing.Dict[str, typing.Optional[GetSimulationTestResponseModelDynamicVariablesValue]]
    ] = None
    chat_history: typing.Optional[typing.List[ConversationHistoryTranscriptCommonModelOutput]] = None
    success_condition: typing.Optional[str] = None
    simulation_scenario: typing.Optional[str] = None
    simulation_max_turns: typing.Optional[int] = None
    id: str
    name: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


TestsUpdateResponse = typing_extensions.Annotated[
    typing.Union[TestsUpdateResponse_Llm, TestsUpdateResponse_Tool, TestsUpdateResponse_Simulation],
    UnionMetadata(discriminant="type"),
]
update_forward_refs(TestsUpdateResponse_Llm)
update_forward_refs(TestsUpdateResponse_Tool)
update_forward_refs(TestsUpdateResponse_Simulation)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .agent_call_limits import AgentCallLimits
from .agent_testing_settings import AgentTestingSettings
from .agent_workspace_overrides_input import AgentWorkspaceOverridesInput
from .auth_settings import AuthSettings
from .conversation_initiation_client_data_config_input import ConversationInitiationClientDataConfigInput
from .evaluation_settings import EvaluationSettings
from .literal_json_schema_property import LiteralJsonSchemaProperty
from .privacy_config_input import PrivacyConfigInput
from .widget_config import WidgetConfig


class AgentPlatformSettingsRequestModel(UncheckedBaseModel):
    evaluation: typing.Optional[EvaluationSettings] = pydantic.Field(default=None)
    """
    Settings for evaluation
    """

    widget: typing.Optional[WidgetConfig] = pydantic.Field(default=None)
    """
    Configuration for the widget
    """

    data_collection: typing.Optional[typing.Dict[str, LiteralJsonSchemaProperty]] = pydantic.Field(default=None)
    """
    Data collection settings
    """

    overrides: typing.Optional[ConversationInitiationClientDataConfigInput] = pydantic.Field(default=None)
    """
    Additional overrides for the agent during conversation initiation
    """

    workspace_overrides: typing.Optional[AgentWorkspaceOverridesInput] = pydantic.Field(default=None)
    """
    Workspace overrides for the agent
    """

    testing: typing.Optional[AgentTestingSettings] = pydantic.Field(default=None)
    """
    Testing configuration for the agent
    """

    archived: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the agent is archived
    """

    summary_language: typing.Optional[str] = pydantic.Field(default=None)
    """
    Language for all conversation analysis outputs (summaries, titles, evaluation rationales, data collection rationales). If not set, the language will be inferred from the conversation. Must be one of the supported conversation languages.
    """

    auth: typing.Optional[AuthSettings] = pydantic.Field(default=None)
    """
    Settings for authentication
    """

    call_limits: typing.Optional[AgentCallLimits] = pydantic.Field(default=None)
    """
    Call limits for the agent
    """

    privacy: typing.Optional[PrivacyConfigInput] = pydantic.Field(default=None)
    """
    Privacy settings for the agent
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata


class GetPronunciationDictionaryWithRulesResponseModelRulesItem_Alias(UncheckedBaseModel):
    type: typing.Literal["alias"] = "alias"
    string_to_replace: str
    case_sensitive: typing.Optional[bool] = None
    word_boundaries: typing.Optional[bool] = None
    alias: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class GetPronunciationDictionaryWithRulesResponseModelRulesItem_Phoneme(UncheckedBaseModel):
    type: typing.Literal["phoneme"] = "phoneme"
    string_to_replace: str
    case_sensitive: typing.Optional[bool] = None
    word_boundaries: typing.Optional[bool] = None
    phoneme: str
    alphabet: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


GetPronunciationDictionaryWithRulesResponseModelRulesItem = typing_extensions.Annotated[
    typing.Union[
        GetPronunciationDictionaryWithRulesResponseModelRulesItem_Alias,
        GetPronunciationDictionaryWithRulesResponseModelRulesItem_Phoneme,
    ],
    UnionMetadata(discriminant="type"),
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .guardrail_execution_mode import GuardrailExecutionMode


class CustomGuardrailConfig(UncheckedBaseModel):
    """
    Single custom guardrail configuration
    """

    is_enabled: typing.Optional[bool] = None
    name: str = pydantic.Field()
    """
    User-facing name for this guardrail
    """

    prompt: str = pydantic.Field()
    """
    Instruction describing what to block, e.g. 'don't talk about politics'
    """

    execution_mode: typing.Optional[GuardrailExecutionMode] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DependentUnknownAgentIdentifier(UncheckedBaseModel):
    """
    A model that represents an agent dependent on a knowledge base/tools
    to which the user has no direct access.
    """

    referenced_resource_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    If the agent is a transitive dependent, contains IDs of the resources that the agent depends on directly.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class SourceConfigJson(UncheckedBaseModel):
    """
    JSON-serializable source configuration for tool configs.

    This can override existing sources or define entirely new ones.
    For new sources, collection_name is required.
    """

    name: str = pydantic.Field()
    """
    Source name (can be existing or new)
    """

    db_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    MongoDB database name. Default: eleven_customer_support
    """

    collection_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    MongoDB collection name. Required for new sources.
    """

    k_dense: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of chunks from vector search
    """

    k_keyword: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of chunks from BM25 search
    """

    dense_weight: typing.Optional[float] = pydantic.Field(default=None)
    """
    Weight for vector results
    """

    keyword_weight: typing.Optional[float] = pydantic.Field(default=None)
    """
    Weight for BM25 results
    """

    source_weight: typing.Optional[float] = pydantic.Field(default=None)
    """
    Weight for cross-source merging
    """

    vector_index_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vector search index name. Default: 'default'
    """

    embedding_field: typing.Optional[str] = pydantic.Field(default=None)
    """
    Field containing embeddings. Default: 'embedding'
    """

    content_field: typing.Optional[str] = pydantic.Field(default=None)
    """
    Field containing text content. Default: 'content'
    """

    enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether this source is active
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .body_text_to_speech_full_apply_text_normalization import BodyTextToSpeechFullApplyTextNormalization
    from .body_text_to_speech_full_with_timestamps_apply_text_normalization import (
        BodyTextToSpeechFullWithTimestampsApplyTextNormalization,
    )
    from .body_text_to_speech_stream_apply_text_normalization import BodyTextToSpeechStreamApplyTextNormalization
    from .body_text_to_speech_stream_with_timestamps_apply_text_normalization import (
        BodyTextToSpeechStreamWithTimestampsApplyTextNormalization,
    )
    from .text_to_speech_convert_request_output_format import TextToSpeechConvertRequestOutputFormat
    from .text_to_speech_convert_with_timestamps_request_output_format import (
        TextToSpeechConvertWithTimestampsRequestOutputFormat,
    )
    from .text_to_speech_stream_request_output_format import TextToSpeechStreamRequestOutputFormat
    from .text_to_speech_stream_with_timestamps_request_output_format import (
        TextToSpeechStreamWithTimestampsRequestOutputFormat,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BodyTextToSpeechFullApplyTextNormalization": ".body_text_to_speech_full_apply_text_normalization",
    "BodyTextToSpeechFullWithTimestampsApplyTextNormalization": ".body_text_to_speech_full_with_timestamps_apply_text_normalization",
    "BodyTextToSpeechStreamApplyTextNormalization": ".body_text_to_speech_stream_apply_text_normalization",
    "BodyTextToSpeechStreamWithTimestampsApplyTextNormalization": ".body_text_to_speech_stream_with_timestamps_apply_text_normalization",
    "TextToSpeechConvertRequestOutputFormat": ".text_to_speech_convert_request_output_format",
    "TextToSpeechConvertWithTimestampsRequestOutputFormat": ".text_to_speech_convert_with_timestamps_request_output_format",
    "TextToSpeechStreamRequestOutputFormat": ".text_to_speech_stream_request_output_format",
    "TextToSpeechStreamWithTimestampsRequestOutputFormat": ".text_to_speech_stream_with_timestamps_request_output_format",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BodyTextToSpeechFullApplyTextNormalization",
    "BodyTextToSpeechFullWithTimestampsApplyTextNormalization",
    "BodyTextToSpeechStreamApplyTextNormalization",
    "BodyTextToSpeechStreamWithTimestampsApplyTextNormalization",
    "TextToSpeechConvertRequestOutputFormat",
    "TextToSpeechConvertWithTimestampsRequestOutputFormat",
    "TextToSpeechStreamRequestOutputFormat",
    "TextToSpeechStreamWithTimestampsRequestOutputFormat",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.unchecked_base_model import UncheckedBaseModel, UnionMetadata


class BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings_Coached(UncheckedBaseModel):
    type: typing.Literal["coached"] = "coached"
    memory_base_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings_None(UncheckedBaseModel):
    type: typing.Literal["none"] = "none"
    memory_base_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings = typing_extensions.Annotated[
    typing.Union[
        BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings_Coached,
        BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings_None,
    ],
    UnionMetadata(discriminant="type"),
]
